@@ -1,13 +1,11 @@
 """
-PyMove
-======
+PyMove.
 
 Provides  processing and visualization of trajectories and other
 spatial-temporal data
 
 """
 
-from ._version import __version__
 from .core import grid
 from .core.dask import DaskMoveDataFrame
 from .core.dataframe import MoveDataFrame
@@ -21,9 +19,12 @@ from .semantic import semantic
 from .utils import (
     constants,
     conversions,
+    data_augmentation,
     datetime,
     distances,
+    geoutils,
     integration,
+    log,
     math,
     mem,
     trajectories,
@@ -31,3 +32,5 @@ from .utils import (
 )
 from .utils.trajectories import read_csv
 from .visualization import folium, matplotlib
+
+__version__ = '3.0.1'
