@@ -1,4 +1,7 @@
-from typing import Dict, List, Optional, Text, Union
+"""MoveDataFrame class."""
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from dateutil.parser._parser import ParserError
 from pandas.core.frame import DataFrame
@@ -12,21 +15,28 @@ from pymove.utils.constants import (
     TYPE_PANDAS,
 )
 
+if TYPE_CHECKING:
+    from pymove.core.dask import DaskMoveDataFrame
+    from pymove.core.pandas import PandasMoveDataFrame
+
 
 class MoveDataFrame:
+    """Auxiliary class to check and transform data into Pymove Dataframes."""
+
     @staticmethod
-    def __new__(
+    def __new__(  # type: ignore[misc]
         self,
-        data: Union[DataFrame, Dict, List],
-        latitude: Optional[Text] = LATITUDE,
-        longitude: Optional[Text] = LONGITUDE,
-        datetime: Optional[Text] = DATETIME,
-        traj_id: Optional[Text] = TRAJ_ID,
-        type_: Optional[Text] = TYPE_PANDAS,
-        n_partitions: Optional[int] = 1,
-    ):
+        data: DataFrame | dict | list,
+        latitude: str = LATITUDE,
+        longitude: str = LONGITUDE,
+        datetime: str = DATETIME,
+        traj_id: str = TRAJ_ID,
+        type_: str = TYPE_PANDAS,
+        n_partitions: int = 1,
+    ) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame':
         """
         Creates the PyMove dataframe, which must contain latitude, longitude and datetime.
+
         The dataframe can be a pandas or dask dataframe.
 
         Parameters
@@ -43,7 +53,7 @@ class MoveDataFrame:
             Represents column name trajectory id, by default TRAJ_ID
         type_ : str, optional
             Number of partitions of the dask dataframe, by default TYPE_PANDAS
-        n_partitions : Optional[int], optional
+        n_partitions : int, optional
             Amount of partitions for dask dataframe, by default 1
 
         Raises
@@ -54,7 +64,6 @@ class MoveDataFrame:
             If the data types can't be converted.
 
         """
-
         if type_ == TYPE_PANDAS:
             from pymove.core.pandas import PandasMoveDataFrame
             return PandasMoveDataFrame(
@@ -65,12 +74,14 @@ class MoveDataFrame:
             return DaskMoveDataFrame(
                 data, latitude, longitude, datetime, traj_id, n_partitions
             )
+        raise TypeError(
+            f'Unknown MoveDataFrame type {type_}, use {TYPE_PANDAS} or {TYPE_DASK}'
+        )
 
     @staticmethod
     def has_columns(data: DataFrame) -> bool:
         """
-        Checks whether the received dataset has 'lat', 'lon', 'datetime'
-        columns.
+        Checks whether the received dataset has 'lat', 'lon', 'datetime' columns.
 
         Parameters
         ----------
@@ -83,7 +94,6 @@ class MoveDataFrame:
             Represents whether or not you have the required columns
 
         """
-
         cols = data.columns
         if LATITUDE in cols and LONGITUDE in cols and DATETIME in cols:
             return True
@@ -107,7 +117,6 @@ class MoveDataFrame:
             If the data types can't be converted
 
         """
-
         try:
             if data.dtypes[LATITUDE] != 'float64':
                 data[LATITUDE] = data[LATITUDE].astype('float64')
@@ -115,20 +124,19 @@ class MoveDataFrame:
                 data[LONGITUDE] = data[LONGITUDE].astype('float64')
             if data.dtypes[DATETIME] != 'datetime64[ns]':
                 data[DATETIME] = data[DATETIME].astype('datetime64[ns]')
-        except KeyError as e:
-            print('dataframe missing one of lat, lon, datetime columns.')
-            raise e
-        except (ValueError, ParserError) as e:
-            print('dtypes cannot be converted.')
-            raise e
+        except KeyError:
+            raise KeyError('dataframe missing one of lat, lon, datetime columns.')
+        except ParserError:
+            raise ParserError('datetime column cannot be parsed')
+        except ValueError:
+            raise ValueError('dtypes cannot be converted.')
 
     @staticmethod
     def format_labels(
-        current_id: Text, current_lat: Text, current_lon: Text, current_datetime: Text
-    ) -> Dict:
+        current_id: str, current_lat: str, current_lon: str, current_datetime: str
+    ) -> dict:
         """
-        Format the labels for the PyMove lib pattern labels output
-        lat, lon and datatime.
+        Format the labels for the PyMove lib pattern labels output lat, lon and datatime.
 
         Parameters
         ----------
@@ -148,7 +156,6 @@ class MoveDataFrame:
             to format of PyMove column.
 
         """
-
         return {
             current_id: TRAJ_ID,
             current_lon: LONGITUDE,
