@@ -1,10 +1,11 @@
+"""Grid class."""
+from __future__ import annotations
+
 import math
-from typing import Callable, Dict, Optional, Text, Tuple, Union
+from typing import Callable
 
 import joblib
-import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib.pyplot import figure
 from pandas import DataFrame
 from shapely.geometry import Polygon
 
@@ -15,20 +16,21 @@ from pymove.utils.constants import (
     INDEX_GRID_LON,
     LATITUDE,
     LONGITUDE,
-    POLYGON,
     TRAJ_ID,
 )
 from pymove.utils.conversions import lat_meters
-from pymove.utils.log import progress_bar
+from pymove.utils.log import logger, progress_bar
 from pymove.utils.mem import begin_operation, end_operation
 
 
 class Grid:
+    """PyMove class representing a grid."""
+
     def __init__(
         self,
-        data: Union[DataFrame, Dict],
-        cell_size: Optional[float] = None,
-        meters_by_degree: Optional[float] = lat_meters(-3.8162973555)
+        data: DataFrame | dict,
+        cell_size: float | None = None,
+        meters_by_degree: float | None = None
     ):
         """
         Creates a virtual grid from the trajectories.
@@ -43,20 +45,29 @@ class Grid:
                 'grid_size_lat_y': lat y size of grid,
                 'grid_size_lon_x': lon x size of grid,
                 'cell_size_by_degree': cell size in radians,
-        cell_size : float, optional
+        cell_size : float
             Represents grid cell size, by default None
         meters_by_degree : float, optional
             Represents the corresponding meters of lat by degree,
-                by default lat_meters(-3.8162973555)
+                by default lat_meters(-3.71839)
+
+        Raises
+        ------
+        ValueError
+            If one of data or cell grid is not provided
         """
-        self.last_operation = None
+        self.last_operation: dict = dict()
+        if meters_by_degree is None:
+            meters_by_degree = lat_meters(-3.71839)
         if isinstance(data, dict):
             self._grid_from_dict(data)
-        else:
+        elif cell_size is not None:
             self._create_virtual_grid(data, cell_size, meters_by_degree)
+        else:
+            raise ValueError('Must pass either data or cell size.')
         self.grid_polygon = None
 
-    def get_grid(self) -> Dict:
+    def get_grid(self) -> dict:
         """
         Returns the grid object in a dict format.
 
@@ -78,7 +89,7 @@ class Grid:
             'cell_size_by_degree': self.cell_size_by_degree,
         }
 
-    def _grid_from_dict(self, dict_grid: Dict):
+    def _grid_from_dict(self, dict_grid: dict):
         """
         Coverts the dict grid to a Grid object.
 
@@ -97,6 +108,7 @@ class Grid:
         self.grid_size_lat_y = dict_grid['grid_size_lat_y']
         self.grid_size_lon_x = dict_grid['grid_size_lon_x']
         self.cell_size_by_degree = dict_grid['cell_size_by_degree']
+        self.grid_polygon = None
 
     def _create_virtual_grid(
         self, data: DataFrame, cell_size: float, meters_by_degree: float
@@ -114,15 +126,13 @@ class Grid:
             Represents the meters degree of latitude
 
         """
-
         operation = begin_operation('_create_virtual_grid')
 
         bbox = data.get_bbox()
-        print('\nCreating a virtual grid without polygons')
+        logger.debug('\nCreating a virtual grid without polygons')
 
-        # Latitude in Fortaleza: -3.8162973555
         cell_size_by_degree = cell_size / meters_by_degree
-        print('...cell size by degree: %s' % cell_size_by_degree)
+        logger.debug('...cell size by degree: %s' % cell_size_by_degree)
 
         lat_min_y = bbox[0]
         lon_min_x = bbox[1]
@@ -148,7 +158,7 @@ class Grid:
             round((lon_max_x - lon_min_x) / cell_size_by_degree)
         )
 
-        print(
+        logger.debug(
             '...grid_size_lat_y:%s\ngrid_size_lon_x:%s'
             % (grid_size_lat_y, grid_size_lon_x)
         )
@@ -158,20 +168,21 @@ class Grid:
         self.grid_size_lat_y = grid_size_lat_y
         self.grid_size_lon_x = grid_size_lon_x
         self.cell_size_by_degree = cell_size_by_degree
-        print('\n..A virtual grid was created')
+        logger.debug('\n..A virtual grid was created')
 
         self.last_operation = end_operation(operation)
 
     def create_update_index_grid_feature(
         self,
         data: DataFrame,
-        unique_index: Optional[bool] = True,
-        label_dtype: Optional[Callable] = np.int64,
-        sort: Optional[bool] = True
+        unique_index: bool = True,
+        label_dtype: Callable = np.int64,
+        sort: bool = True
     ):
         """
-        Create or update index grid feature. It not necessary pass dic_grid,
-        because if don't pass, the function create a dic_grid.
+        Create or update index grid feature.
+
+        It is not necessary pass dic_grid, because it creates a dic_grid if not provided.
 
         Parameters
         ----------
@@ -179,42 +190,37 @@ class Grid:
             Represents the dataset with contains lat, long and datetime.
         unique_index: bool, optional
             How to index the grid, by default True
-        label_dtype : Optional[Callable], optional
+        label_dtype : Callable, optional
             Represents the type of a value of new column in dataframe, by default np.int64
         sort : bool, optional
             Represents if needs to sort the dataframe, by default True
 
         """
-
         operation = begin_operation('create_update_index_grid_feature')
 
-        print('\nCreating or updating index of the grid feature..\n')
-        try:
-            if sort:
-                data.sort_values([TRAJ_ID, DATETIME], inplace=True)
-            lat_, lon_ = self.point_to_index_grid(
-                data[LATITUDE], data[LONGITUDE]
-            )
-            lat_, lon_ = label_dtype(lat_), label_dtype(lon_)
-            dict_grid = self.get_grid()
-            if unique_index:
-                data[INDEX_GRID] = lon_ * dict_grid['grid_size_lat_y'] + lat_
-            else:
-                data[INDEX_GRID_LAT] = lat_
-                data[INDEX_GRID_LON] = lon_
-            self.last_operation = end_operation(operation)
-        except Exception as e:
-            self.last_operation = end_operation(operation)
-            raise e
+        logger.debug('\nCreating or updating index of the grid feature..\n')
+        if sort:
+            data.sort_values([TRAJ_ID, DATETIME], inplace=True)
+        lat_, lon_ = self.point_to_index_grid(
+            data[LATITUDE], data[LONGITUDE]
+        )
+        lat_, lon_ = label_dtype(lat_), label_dtype(lon_)
+        dict_grid = self.get_grid()
+        if unique_index:
+            data[INDEX_GRID] = lon_ * dict_grid['grid_size_lat_y'] + lat_
+        else:
+            data[INDEX_GRID_LAT] = lat_
+            data[INDEX_GRID_LON] = lon_
+        self.last_operation = end_operation(operation)
 
     def convert_two_index_grid_to_one(
         self,
         data: DataFrame,
-        label_grid_lat: Optional[Text] = INDEX_GRID_LAT,
-        label_grid_lon: Optional[Text] = INDEX_GRID_LON,
+        label_grid_lat: str = INDEX_GRID_LAT,
+        label_grid_lon: str = INDEX_GRID_LON,
     ):
         """
-        Converts grid lat-lon ids to unique values
+        Converts grid lat-lon ids to unique values.
 
         Parameters
         ----------
@@ -233,10 +239,10 @@ class Grid:
     def convert_one_index_grid_to_two(
         self,
         data: DataFrame,
-        label_grid_index: Optional[Text] = INDEX_GRID,
+        label_grid_index: str = INDEX_GRID,
     ):
         """
-        Converts grid lat-lon ids to unique values
+        Converts grid lat-lon ids to unique values.
 
         Parameters
         ----------
@@ -268,7 +274,6 @@ class Grid:
             Represents a polygon of this cell in a grid.
 
         """
-
         operation = begin_operation('create_one_polygon_to_point_on_grid')
 
         cell_size = self.cell_size_by_degree
@@ -286,14 +291,14 @@ class Grid:
 
     def create_all_polygons_on_grid(self):
         """
-        Create all polygons that are represented in a grid and store them in a
-        new dic_grid key .
+        Create all polygons that are represented in a grid.
+
+        Stores the polygons in the `grid_polygon` key
 
         """
-
         operation = begin_operation('create_all_polygons_on_grid')
 
-        print('\nCreating all polygons on virtual grid', flush=True)
+        logger.debug('\nCreating all polygons on virtual grid')
         grid_polygon = np.array(
             [
                 [None for _ in range(self.grid_size_lon_x)]
@@ -302,7 +307,7 @@ class Grid:
         )
         lat_init = self.lat_min_y
         cell_size = self.cell_size_by_degree
-        for i in progress_bar(range(self.grid_size_lat_y)):
+        for i in progress_bar(range(self.grid_size_lat_y), desc='Creating polygons'):
             lon_init = self.lon_min_x
             for j in range(self.grid_size_lon_x):
                 # Cria o polygon da célula
@@ -315,7 +320,7 @@ class Grid:
                 lon_init += cell_size
             lat_init += cell_size
         self.grid_polygon = grid_polygon
-        print('...geometries saved on Grid grid_polygon property')
+        logger.debug('...geometries saved on Grid grid_polygon property')
         self.last_operation = end_operation(operation)
 
     def create_all_polygons_to_all_point_on_grid(
@@ -336,7 +341,6 @@ class Grid:
             where polygons were saved.
 
         """
-
         operation = begin_operation('create_all_polygons_to_all_point_on_grid')
         if INDEX_GRID_LAT not in data or INDEX_GRID_LON not in data:
             self.create_update_index_grid_feature(data, unique_index=False)
@@ -349,12 +353,12 @@ class Grid:
             ), axis=1
         )
 
-        print('...polygons were created')
+        logger.debug('...polygons were created')
         datapolygons['polygon'] = polygons
         self.last_operation = end_operation(operation)
         return datapolygons
 
-    def point_to_index_grid(self, event_lat: float, event_lon: float) -> Tuple[int, int]:
+    def point_to_index_grid(self, event_lat: float, event_lon: float) -> tuple[int, int]:
         """
         Locate the coordinates x and y in a grid of point (lat, long).
 
@@ -372,7 +376,6 @@ class Grid:
             Represents the index x in a grid of a point (lat, long)
 
         """
-
         operation = begin_operation('create_all_polygons_to_all_point_on_grid')
 
         indexes_lat_y = np.floor(
@@ -381,7 +384,7 @@ class Grid:
         indexes_lon_x = np.floor(
             (np.float64(event_lon) - self.lon_min_x) / self.cell_size_by_degree
         )
-        print(
+        logger.debug(
             '...[%s,%s] indexes were created to lat and lon'
             % (indexes_lat_y.size, indexes_lon_x.size)
         )
@@ -389,7 +392,7 @@ class Grid:
 
         return indexes_lat_y, indexes_lon_x
 
-    def save_grid_pkl(self, filename: Text):
+    def save_grid_pkl(self, filename: str):
         """
         Save a grid with new file .pkl.
 
@@ -399,13 +402,12 @@ class Grid:
             Represents the name of a file.
 
         """
-
         operation = begin_operation('save_grid_pkl')
         with open(filename, 'wb') as f:
             joblib.dump(self.get_grid(), f)
         self.last_operation = end_operation(operation)
 
-    def read_grid_pkl(self, filename: Text) -> 'Grid':
+    def read_grid_pkl(self, filename: str) -> 'Grid':
         """
         Read grid dict from a file .pkl.
 
@@ -427,77 +429,9 @@ class Grid:
         self.last_operation = end_operation(operation)
         return grid
 
-    def show_grid_polygons(
-        self,
-        data: DataFrame,
-        markersize: Optional[float] = 10,
-        linewidth: Optional[float] = 2,
-        figsize: Optional[Tuple[int, int]] = (10, 10),
-        return_fig: Optional[bool] = True,
-        save_fig: Optional[bool] = False,
-        name: Optional[Text] = 'grid.png',
-    ) -> Optional[figure]:
-        """
-        Generate a visualization with grid polygons.
-
-        Parameters
-        ----------
-        data : DataFrame
-            Input trajectory data
-        markersize : float, optional
-            Represents visualization size marker, by default 10
-        linewidth : float, optional
-            Represents visualization size line, by default 2
-        figsize : tuple(int, int), optional
-            Represents the size (float: width, float: height) of a figure,
-                by default (10, 10)
-        return_fig : bool, optional
-            Represents whether or not to save the generated picture, by default True
-        save_fig : bool, optional
-            Wether to save the figure, by default False
-        name : str, optional
-            Represents name of a file, by default 'grid.png'
-
-        Returns
-        -------
-        Optional[figure]
-            The generated picture or None
-
-        Raises
-        ------
-            If the dataframe does not contains the POLYGON feature
-        IndexError
-            If there is no user with the id passed
-
-        """
-        if POLYGON not in data:
-            raise KeyError('POLYGON feature not in dataframe')
-
-        data.dropna(subset=[POLYGON], inplace=True)
-
-        operation = begin_operation('show_grid_polygons')
-
-        fig = plt.figure(figsize=figsize)
-
-        for _, row in data.iterrows():
-            xs, ys = row[POLYGON].exterior.xy
-            plt.plot(ys, xs, 'g', linewidth=linewidth, markersize=markersize)
-        xs_start, ys_start = data.iloc[0][POLYGON].exterior.xy
-        xs_end, ys_end = data.iloc[-1][POLYGON].exterior.xy
-        plt.plot(ys_start, xs_start, 'bo', markersize=markersize * 1.5)
-        plt.plot(ys_end, xs_end, 'bX', markersize=markersize * 1.5)  # start point
-
-        if save_fig:
-            plt.savefig(fname=name, fig=fig)
-
-        self.last_operation = end_operation(operation)
-
-        if return_fig:
-            return fig
-
     def __repr__(self) -> str:
         """
-        String representation of grid
+        String representation of grid.
 
         Returns
         -------
@@ -508,5 +442,5 @@ class Grid:
             grid_size_lon_x: grid longitude size
             cell_size_by_degree: grid cell size
         """
-        text = ['{}: {}'.format(k, v) for k, v in self.get_grid().items()]
+        text = [f'{k}: {v}' for k, v in self.get_grid().items()]
         return '\n'.join(text)
