@@ -1,4 +1,14 @@
-from typing import Callable, Dict, Optional, Text, Union
+"""
+Clustering operations.
+
+elbow_method,
+gap_statistic,
+dbscan_clustering
+
+"""
+from __future__ import annotations
+
+from typing import Callable
 
 import numpy as np
 from pandas import DataFrame
@@ -6,20 +16,21 @@ from sklearn.cluster import DBSCAN, KMeans
 
 from pymove.utils.constants import EARTH_RADIUS, LATITUDE, LONGITUDE, N_CLUSTER
 from pymove.utils.conversions import meters_to_eps
-from pymove.utils.log import progress_bar, timer_decorator
+from pymove.utils.log import logger, progress_bar, timer_decorator
 
 
 @timer_decorator
 def elbow_method(
     move_data: DataFrame,
-    k_initial: Optional[int] = 1,
-    max_clusters: Optional[int] = 15,
-    k_iteration: Optional[int] = 1,
-    random_state: Optional[int] = None
-) -> Dict:
+    k_initial: int = 1,
+    max_clusters: int = 15,
+    k_iteration: int = 1,
+    random_state: int | None = None
+) -> dict:
     """
-    Determines the optimal number of clusters in the range set by the user using
-    the elbow method.
+    Determines the optimal number of clusters.
+
+    In the range set by the user using the elbow method.
 
     Parameters
     ----------
@@ -54,12 +65,14 @@ def elbow_method(
         }
 
     """
-
-    message = 'Executing Elbow Method to:\n...K of %srs to %srs from k_iteration:%srs\n'
-    message = message % (k_initial, max_clusters, k_iteration)
-    print(message, flush=True)
+    message = 'Executing Elbow Method for {} to {} clusters at {} steps\n'.format(
+        k_initial, max_clusters, k_iteration
+    )
+    logger.debug(message)
     inertia_dic = {}
-    for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
+    for k in progress_bar(
+        range(k_initial, max_clusters + 1, k_iteration), desc='Running KMeans'
+    ):
         km = KMeans(n_clusters=k, random_state=random_state)
         inertia_dic[k] = km.fit(move_data[[LATITUDE, LONGITUDE]]).inertia_
     return inertia_dic
@@ -68,15 +81,16 @@ def elbow_method(
 @timer_decorator
 def gap_statistic(
     move_data: DataFrame,
-    nrefs: Optional[int] = 3,
-    k_initial: Optional[int] = 1,
-    max_clusters: Optional[int] = 15,
-    k_iteration: Optional[int] = 1,
-    random_state: Optional[int] = None
-) -> Dict:
+    nrefs: int = 3,
+    k_initial: int = 1,
+    max_clusters: int = 15,
+    k_iteration: int = 1,
+    random_state: int | None = None
+) -> dict:
     """
-    Calculates optimal clusters numbers using Gap Statistic from Tibshirani,
-    Walther, Hastie.
+    Calculates optimal clusters numbers using Gap Statistic.
+
+    From Tibshirani, Walther, Hastie.
 
     Parameters
     ----------
@@ -105,13 +119,15 @@ def gap_statistic(
     https://anaconda.org/milesgranger/gap-statistic/notebook
 
     """
-
-    message = 'Executing Gap Statistic to:\n...K of %srs to %srs from k_iteration:%srs\n'
-    message = message % (k_initial, max_clusters, k_iteration)
-    print(message, flush=True)
+    message = 'Executing Gap Statistic for {} to {} clusters at {} steps\n'.format(
+        k_initial, max_clusters, k_iteration
+    )
+    logger.debug(message)
     gaps = {}
     np.random.seed(random_state)
-    for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
+    for k in progress_bar(
+        range(k_initial, max_clusters + 1, k_iteration), desc='Running KMeans'
+    ):
         # Holder for reference dispersion results
         ref_disps = np.zeros(nrefs)
         # For n references, generate random sample and perform kmeans
@@ -136,15 +152,15 @@ def gap_statistic(
 @timer_decorator
 def dbscan_clustering(
     move_data: DataFrame,
-    cluster_by: Text,
-    meters: Optional[int] = 10,
-    min_sample: Optional[float] = 1680 / 2,
-    earth_radius: Optional[float] = EARTH_RADIUS,
-    metric: Optional[Union[Text, Callable]] = 'euclidean',
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    cluster_by: str,
+    meters: int = 10,
+    min_sample: float = 1680 / 2,
+    earth_radius: float = EARTH_RADIUS,
+    metric: str | Callable = 'euclidean',
+    inplace: bool = False
+) -> DataFrame | None:
     """
-    Performs density based clustering on the move_dataframe according to cluster_by
+    Performs density based clustering on the move_dataframe according to cluster_by.
 
     Parameters
     ----------
