@@ -1,4 +1,10 @@
-from typing import Optional, Text
+"""
+Compression operations.
+
+compress_segment_stop_to_point
+
+"""
+from __future__ import annotations
 
 import numpy as np
 from pandas import DataFrame
@@ -15,23 +21,24 @@ from pymove.utils.constants import (
     STOP,
     TRAJ_ID,
 )
-from pymove.utils.log import progress_bar, timer_decorator
+from pymove.utils.log import logger, progress_bar, timer_decorator
 
 
 @timer_decorator
 def compress_segment_stop_to_point(
     move_data: DataFrame,
-    label_segment: Optional[Text] = SEGMENT_STOP,
-    label_stop: Optional[Text] = STOP,
-    point_mean: Optional[Text] = 'default',
-    drop_moves: Optional[bool] = False,
-    label_id: Optional[Text] = TRAJ_ID,
-    dist_radius: Optional[float] = 30,
-    time_radius: Optional[float] = 900,
-    inplace: Optional[bool] = False,
+    label_segment: str = SEGMENT_STOP,
+    label_stop: str = STOP,
+    point_mean: str = 'default',
+    drop_moves: bool = False,
+    label_id: str = TRAJ_ID,
+    dist_radius: float = 30,
+    time_radius: float = 900,
+    inplace: bool = False,
 ) -> DataFrame:
     """
     Compress the trajectories using the stop points in the dataframe.
+
     Compress a segment to point setting lat_mean e lon_mean to each segment.
 
     Parameters
@@ -85,16 +92,15 @@ def compress_segment_stop_to_point(
             the all points into segment
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
     if (label_segment not in move_data) & (label_stop not in move_data):
         create_or_update_move_stop_by_dist_time(
-            move_data, dist_radius, time_radius, label_id
+            move_data, dist_radius, time_radius, label_id, inplace=True
         )
 
-    print('...setting mean to lat and lon...')
+    logger.debug('...setting mean to lat and lon...')
     lat_mean = np.full(move_data.shape[0], -1.0, dtype=np.float64)
     lon_mean = np.full(move_data.shape[0], -1.0, dtype=np.float64)
 
@@ -102,9 +108,9 @@ def compress_segment_stop_to_point(
         lat_mean[move_data[~move_data[label_stop]].index] = np.NaN
         lon_mean[move_data[~move_data[label_stop]].index] = np.NaN
     else:
-        print('...move segments will be dropped...')
+        logger.debug('...move segments will be dropped...')
 
-    print('...get only segments stop...', flush=True)
+    logger.debug('...get only segments stop...')
     segments = move_data[move_data[label_stop]][label_segment].unique()
 
     for idx in progress_bar(
@@ -120,8 +126,6 @@ def compress_segment_stop_to_point(
             ind_end = move_data[filter_].iloc[[-1]].index
 
             if point_mean == 'default':
-                # print('...Lat and lon are defined based on point
-                # that repeats most within the segment')
                 p = (
                     move_data[filter_]
                     .groupby([LATITUDE, LONGITUDE], as_index=False)
@@ -142,7 +146,7 @@ def compress_segment_stop_to_point(
                 lat_mean[ind_end] = move_data.loc[filter_][LATITUDE].mean()
                 lon_mean[ind_end] = move_data.loc[filter_][LONGITUDE].mean()
         else:
-            print('There are segments with only one point: {}'.format(idx))
+            logger.debug(f'There are segments with only one point: {idx}')
 
     move_data[LAT_MEAN] = lat_mean
     move_data[LON_MEAN] = lon_mean
@@ -158,10 +162,10 @@ def compress_segment_stop_to_point(
     shape_drop = move_data[filter_drop].shape[0]
 
     if shape_drop > 0:
-        print('...Dropping %s points...' % shape_drop)
+        logger.debug('...Dropping %s points...' % shape_drop)
         move_data.drop(move_data[filter_drop].index, inplace=True)
 
-    print(
+    logger.debug(
         '...Shape_before: %s\n...Current shape: %s'
         % (shape_before, move_data.shape[0])
     )
