@@ -1,32 +1,53 @@
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Text, Tuple, Union
+"""
+Filtering operations.
+
+get_bbox_by_radius,
+by_bbox,
+by_datetime,
+by_label,
+by_id,
+by_tid,
+clean_consecutive_duplicates,
+clean_gps_jumps_by_distance,
+clean_gps_nearby_points_by_distances,
+clean_gps_nearby_points_by_speed,
+clean_gps_speed_max_radius,
+clean_trajectories_with_few_points,
+clean_trajectories_short_and_few_points,
+clean_id_by_time_max
+
+"""
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Callable
 
 import numpy as np
 from pandas import DataFrame
 
+from pymove.semantic.semantic import outliers
 from pymove.utils.constants import (
     DATETIME,
-    DIST_PREV_TO_NEXT,
-    DIST_TO_NEXT,
     DIST_TO_PREV,
     LATITUDE,
     LONGITUDE,
+    OUTLIER,
     SPEED_TO_PREV,
     TID,
     TIME_TO_PREV,
     TRAJ_ID,
 )
+from pymove.utils.log import logger
 
 if TYPE_CHECKING:
-    from pymove.core.pandas import PandasMoveDataFrame
     from pymove.core.dask import DaskMoveDataFrame
+    from pymove.core.pandas import PandasMoveDataFrame
 
 
 def get_bbox_by_radius(
-    coordinates: Tuple[float, float], radius: Optional[float] = 1000
-) -> List:
+    coordinates: tuple[float, float], radius: float = 1000
+) -> tuple[float, float, float, float]:
     """
-    Defines minimum and maximum coordinates,
-    given a distance radius from a point.
+    Defines minimum and maximum coordinates, given a distance radius from a point.
 
     Parameters
     ----------
@@ -57,15 +78,15 @@ def get_bbox_by_radius(
     lonmin = lon - delta_lon
     lonmax = lon + delta_lon
 
-    return np.rad2deg([latmin, lonmin, latmax, lonmax])
+    return tuple(np.rad2deg([latmin, lonmin, latmax, lonmax]))  # type: ignore
 
 
 def by_bbox(
     move_data: DataFrame,
-    bbox: Tuple[int, int, int, int],
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    bbox: tuple[float, float, float, float],
+    filter_out: bool = False,
+    inplace: bool = False
+) -> DataFrame | None:
     """
     Filters points of the trajectories according to specified bounding box.
 
@@ -89,7 +110,6 @@ def by_bbox(
         Returns dataframe with trajectories points filtered by bounding box or None
 
     """
-
     filter_ = (
         (move_data[LATITUDE] >= bbox[0])
         & (move_data[LONGITUDE] >= bbox[1])
@@ -104,11 +124,11 @@ def by_bbox(
 
 def by_datetime(
     move_data: DataFrame,
-    start_datetime: Optional[Text] = None,
-    end_datetime: Optional[Text] = None,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False,
-) -> Optional[DataFrame]:
+    start_datetime: str | None = None,
+    end_datetime: str | None = None,
+    filter_out: bool = False,
+    inplace: bool = False,
+) -> DataFrame | None:
     """
     Filters trajectories points according to specified time range.
 
@@ -135,7 +155,6 @@ def by_datetime(
         Returns dataframe with trajectories points filtered by time range or None
 
     """
-
     if start_datetime is not None and end_datetime is not None:
         filter_ = (
             (move_data[DATETIME] >= start_datetime)
@@ -155,10 +174,10 @@ def by_datetime(
 def by_label(
     move_data: DataFrame,
     value: Any,
-    label_name: Text,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    label_name: str,
+    filter_out: bool = False,
+    inplace: bool = False
+) -> DataFrame | None:
     """
     Filters trajectories points according to specified value and column label.
 
@@ -185,7 +204,6 @@ def by_label(
         Returns dataframe with trajectories points filtered by label or None
 
     """
-
     filter_ = move_data[label_name] == value
     if filter_out:
         filter_ = ~filter_
@@ -195,11 +213,11 @@ def by_label(
 
 def by_id(
     move_data: DataFrame,
-    id_: Optional[int] = None,
-    label_id: Optional[Text] = TRAJ_ID,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    id_: int | None = None,
+    label_id: str = TRAJ_ID,
+    filter_out: bool = False,
+    inplace: bool = False
+) -> DataFrame | None:
     """
     Filters trajectories points according to specified trajectory id.
 
@@ -228,16 +246,15 @@ def by_id(
         Returns dataframe with trajectories points filtered by id or None
 
     """
-
     return by_label(move_data, id_, label_id, filter_out, inplace)
 
 
 def by_tid(
     move_data: DataFrame,
-    tid_: Optional[Text] = None,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    tid_: str | None = None,
+    filter_out: bool = False,
+    inplace: bool = False
+) -> DataFrame | None:
     """
     Filters trajectories points according to a specified  trajectory tid.
 
@@ -265,94 +282,25 @@ def by_tid(
         Returns a dataframe with trajectories points filtered or None
 
     """
-
     return by_label(move_data, tid_, TID, filter_out, inplace)
 
 
-def outliers(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    jump_coefficient: Optional[float] = 3.0,
-    threshold: Optional[float] = 1,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
-    """
-    Filters trajectories points that are outliers.
-
-    Parameters
-    ----------
-    move_data : dataframe
-        The input trajectory data
-    jump_coefficient : float, optional
-        by default 3
-    threshold : float, optional
-        Minimum value that the distance features must have
-        in order to be considered outliers, by default 1
-    filter_out : bool, optional
-        If set to true, the function will return the points of
-        the trajectories with timestamp outside the time range.
-        The points whithin the time range will be return if filter_out is False.
-        by default False
-    inplace : bool, optional
-        if set to true the original dataframe will be altered to contain
-        the result of the filtering, otherwise a copy will be returned, by default False
-
-
-
-    Returns
-    -------
-    DataFrame
-        Returns a dataframe with the trajectories outliers or None
-
-    """
-
-    if DIST_TO_PREV not in move_data:
-        move_data.generate_dist_features()
-
-    if move_data.index.name is not None:
-        print('...Reset index for filtering\n')
-        move_data.reset_index(inplace=True)
-
-    if (
-        DIST_TO_PREV in move_data
-        and DIST_TO_NEXT
-        and DIST_PREV_TO_NEXT in move_data
-    ):
-        jump = jump_coefficient * move_data[DIST_PREV_TO_NEXT]
-        filter_ = (
-            (move_data[DIST_TO_NEXT] > threshold)
-            & (move_data[DIST_TO_PREV] > threshold)
-            & (move_data[DIST_PREV_TO_NEXT] > threshold)
-            & (jump < move_data[DIST_TO_NEXT])
-            & (jump < move_data[DIST_TO_PREV])
-        )
-
-        if filter_out:
-            filter_ = ~filter_
-
-        print('...Filtering jumps \n')
-        return move_data.drop(index=move_data[~filter_].index, inplace=inplace)
-
-    else:
-        print('...Distances features were not created')
-        return move_data
-
-
 def clean_consecutive_duplicates(
     move_data: DataFrame,
-    subset: Optional[Union[int, Text]] = None,
-    keep: Optional[Union[Text, bool]] = 'first',
-    inplace: Optional[bool] = False
-) -> Optional[DataFrame]:
+    subset: int | str | None = None,
+    keep: str | bool = 'first',
+    inplace: bool = False
+) -> DataFrame | None:
     """
-    Removes consecutive duplicate rows of the Dataframe, optionally only
-    certain columns can be consider.
+    Removes consecutive duplicate rows of the Dataframe.
+
+    Optionally only certain columns can be consider.
 
     Parameters
     ----------
     move_data : dataframe
         The input trajectory data
-    subset : Array of strs, optional
+    subset : Array of str, optional
         Specifies  Column label or sequence of labels, considered for
         identifying duplicates, by default None
     keep : 'first', 'last', optional
@@ -373,7 +321,6 @@ def clean_consecutive_duplicates(
         The filtered trajectories points without consecutive duplicates or None
 
     """
-
     if keep == 'first':
         n = 1
     else:
@@ -404,14 +351,12 @@ def _filter_single_by_max(move_data: DataFrame, **kwargs):
         Filtered dataframe.
 
     """
-
     return move_data[move_data[kwargs['arg1']] <= kwargs['arg2']]
 
 
 def _filter_speed_max_radius(move_data: DataFrame, **kwargs):
     """
-    Filters from a dataframe rows with current or previous row features
-    exceeding value.
+    Filters from a dataframe rows with current or previous row features exceeding value.
 
     Parameters
     ----------
@@ -434,9 +379,9 @@ def _filter_speed_max_radius(move_data: DataFrame, **kwargs):
     return move_data[filter_]
 
 
-def _filter_data(move_data: DataFrame, f: callable, kwargs: Dict):
+def _filter_data(move_data: DataFrame, f: Callable, kwargs: dict):
     """
-    Filter the dataframe using condition from given function
+    Filter the dataframe using condition from given function.
 
     Parameters
     ----------
@@ -457,7 +402,6 @@ def _filter_data(move_data: DataFrame, f: callable, kwargs: Dict):
         Number of rows to be dropped
 
     """
-
     if kwargs['outliers']:
         filter_data_points = f(
             move_data,
@@ -465,6 +409,7 @@ def _filter_data(move_data: DataFrame, f: callable, kwargs: Dict):
             threshold=kwargs['arg2'],
             inplace=False
         )
+        filter_data_points = filter_data_points[filter_data_points[OUTLIER]]
     else:
         filter_data_points = f(
             move_data,
@@ -476,9 +421,9 @@ def _filter_data(move_data: DataFrame, f: callable, kwargs: Dict):
     return filter_data_points, rows_to_drop
 
 
-def _clean_gps(move_data: DataFrame, f: callable, **kwargs):
+def _clean_gps(move_data: DataFrame, f: Callable, **kwargs):
     """
-    Cleans gps points from a dataframe using condition from given function
+    Cleans gps points from a dataframe using condition from given function.
 
     Parameters
     ----------
@@ -497,39 +442,38 @@ def _clean_gps(move_data: DataFrame, f: callable, **kwargs):
         Filtered dataframe.
 
     """
-
     if move_data.index.name is not None:
-        print('...Reset index for filtering\n')
+        logger.debug('...Reset index for filtering\n')
         move_data.reset_index(inplace=True)
 
     filter_data_points, rows_to_drop = _filter_data(move_data, f, kwargs)
 
     sum_drop = 0
     while rows_to_drop > 0:
-        print('...Dropping %s rows of gps points\n' % rows_to_drop)
+        logger.debug('...Dropping %s rows of gps points\n' % rows_to_drop)
         shape_before = move_data.shape[0]
         move_data.drop(index=filter_data_points.index, inplace=True)
         sum_drop = sum_drop + rows_to_drop
-        print(
+        logger.debug(
             '...Rows before: %s, Rows after:%s, Sum drop:%s\n'
             % (shape_before, move_data.shape[0], sum_drop)
         )
 
         filter_data_points, rows_to_drop = _filter_data(move_data, f, kwargs)
 
-    print('%s GPS points were dropped' % sum_drop)
+    logger.debug('%s GPS points were dropped' % sum_drop)
 
     return move_data
 
 
 def clean_gps_jumps_by_distance(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    jump_coefficient: Optional[float] = 3.0,
-    threshold: Optional[float] = 1,
-    label_dtype: Optional[callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    jump_coefficient: float = 3.0,
+    threshold: float = 1,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Removes the trajectories points that are outliers from the dataframe.
 
@@ -556,44 +500,39 @@ def clean_gps_jumps_by_distance(
         The filtered trajectories without the gps jumps or None
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
-    # sum_drop = 0
+        move_data = move_data.copy()
 
-    if DIST_TO_PREV not in move_df:
-        move_df.generate_dist_features(
+    if DIST_TO_PREV not in move_data:
+        move_data.generate_dist_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print(
+    logger.debug(
         '\nCleaning gps jumps by distance to jump_coefficient %s...\n'
         % jump_coefficient
     )
-
-    move_df = _clean_gps(
-        move_df,
+    move_data = _clean_gps(
+        move_data,
         outliers,
         arg1=jump_coefficient,
         arg2=threshold,
         outliers=True
     )
+
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_gps_nearby_points_by_distances(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    radius_area: Optional[float] = 10.0,
-    label_dtype: Optional[callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    radius_area: float = 10.0,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Removes points from the trajectories when the distance between them and the
-    point before is smaller than the value set by the user.
+    Removes points from the trajectories with smaller distance from the point before.
 
     Parameters
     ----------
@@ -617,42 +556,38 @@ def clean_gps_nearby_points_by_distances(
 
     """
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
-    # sum_drop = 0
+        move_data = move_data.copy()
 
-    if DIST_TO_PREV not in move_df:
-        move_df.generate_dist_features(
+    if DIST_TO_PREV not in move_data:
+        move_data.generate_dist_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print(
+    logger.debug(
         '\nCleaning gps points from radius of %s meters\n'
         % radius_area
     )
 
-    move_df = _clean_gps(
-        move_df,
+    move_data = _clean_gps(
+        move_data,
         _filter_single_by_max,
         arg1=DIST_TO_PREV,
         arg2=radius_area,
         outliers=False
     )
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_gps_nearby_points_by_speed(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    speed_radius: Optional[float] = 0.0,
-    label_dtype: Optional[Callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    speed_radius: float = 0.0,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Removes points from the trajectories when the speed of travel between them
-    and the point before is smaller than the value set by the user.
+    Removes points from the trajectories with smaller speed of travel.
 
     Parameters
     ----------
@@ -675,43 +610,41 @@ def clean_gps_nearby_points_by_speed(
         The filtered trajectories without the gps nearby points by speed or None
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
+        move_data = move_data.copy()
 
-    if SPEED_TO_PREV not in move_df:
-        move_df.generate_dist_time_speed_features(
+    if SPEED_TO_PREV not in move_data:
+        move_data.generate_dist_time_speed_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print(
+    logger.debug(
         '\nCleaning gps points using %s speed radius\n'
         % speed_radius
     )
 
-    move_df = _clean_gps(
-        move_df,
+    move_data = _clean_gps(
+        move_data,
         _filter_single_by_max,
         arg1=SPEED_TO_PREV,
         arg2=speed_radius,
         outliers=False
     )
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_gps_speed_max_radius(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    speed_max: Optional[float] = 50.0,
-    label_dtype: Optional[Callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    speed_max: float = 50.0,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Recursively removes trajectories points with speed higher than the value
-    specified by the user. Given any point p of the trajectory, the point will
+    Removes trajectories points with higher speed.
+
+    Given any point p of the trajectory, the point will
     be removed if one of the following happens: if the travel speed from the
     point before p to p is greater than the  max value of speed between adjacent
     points set by the user. Or the travel speed between point p and the next
@@ -741,42 +674,38 @@ def clean_gps_speed_max_radius(
         The filtered trajectories without the gps nearby points or None
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
+        move_data = move_data.copy()
 
-    if SPEED_TO_PREV not in move_df:
-        move_df.generate_dist_time_speed_features(
+    if SPEED_TO_PREV not in move_data:
+        move_data.generate_dist_time_speed_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print(
+    logger.debug(
         '\nClean gps points with speed max > %s meters by seconds'
         % speed_max
     )
 
-    move_df = _clean_gps(
-        move_df,
+    move_data = _clean_gps(
+        move_data,
         _filter_speed_max_radius,
         arg1=SPEED_TO_PREV,
         arg2=speed_max,
         outliers=False
     )
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_trajectories_with_few_points(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_tid: Optional[Text] = TID,
-    min_points_per_trajectory: Optional[int] = 2,
-    inplace: Optional[bool] = False
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_tid: str = TID,
+    min_points_per_trajectory: int = 2,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Removes from the given dataframe, trajectories with fewer points than was
-    specified by the user.
+    Removes from the given dataframe, trajectories with fewer points.
 
     Parameters
     ----------
@@ -802,64 +731,60 @@ def clean_trajectories_with_few_points(
         If the label feature is not in the dataframe
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
+        move_data = move_data.copy()
 
-    if label_tid not in move_df:
+    if label_tid not in move_data:
         raise KeyError('%s not in dataframe' % label_tid)
 
-    print(
+    logger.debug(
         '\nCleaning gps points from trajectories of fewer than %s points\n'
         % min_points_per_trajectory
     )
 
-    if move_df.index.name is not None:
-        print('\n...Reset index for filtering\n')
-        move_df.reset_index(inplace=True)
+    if move_data.index.name is not None:
+        logger.debug('\n...Reset index for filtering\n')
+        move_data.reset_index(inplace=True)
 
-    move_datacount_tid = move_df.groupby(by=label_tid).size()
+    move_datacount_tid = move_data.groupby(by=label_tid).size()
     filter_ = move_datacount_tid < min_points_per_trajectory
     tids_with_few_points = move_datacount_tid[filter_].index
-    shape_before_drop = move_df.shape
-    idx = move_df[move_df[label_tid].isin(tids_with_few_points)].index
+    shape_before_drop = move_data.shape
+    idx = move_data[move_data[label_tid].isin(tids_with_few_points)].index
 
     if idx.shape[0] > 0:
-        print(
+        logger.debug(
             '\n...There are %s ids with few points'
             % tids_with_few_points.shape[0]
         )
-        print(
+        logger.debug(
             '\n...Tids before drop: %s'
-            % move_df[label_tid].unique().shape[0]
+            % move_data[label_tid].unique().shape[0]
         )
-        move_df.drop(index=idx, inplace=True)
-        print(
+        move_data.drop(index=idx, inplace=True)
+        logger.debug(
             '\n...Tids after drop: %s'
-            % move_df[label_tid].unique().shape[0]
+            % move_data[label_tid].unique().shape[0]
         )
-        print(
+        logger.debug(
             '\n...Shape - before drop: %s - after drop: %s'
-            % (shape_before_drop, move_df.shape)
+            % (shape_before_drop, move_data.shape)
         )
 
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_trajectories_short_and_few_points(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TID,
-    min_trajectory_distance: Optional[float] = 100,
-    min_points_per_trajectory: Optional[int] = 2,
-    label_dtype: Optional[Callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TID,
+    min_trajectory_distance: float = 100,
+    min_points_per_trajectory: int = 2,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Eliminates from the given dataframe trajectories with fewer points and
-    shorter length than specified values by the user.
+    Eliminates from the given dataframe trajectories with fewer points and shorter length.
 
     Parameters
     ----------
@@ -889,65 +814,62 @@ def clean_trajectories_short_and_few_points(
         remove_tids_with_few_points must be performed before updating features.
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
+        move_data = move_data.copy()
 
-    print('\nRemove short trajectories...')
+    logger.debug('\nRemove short trajectories...')
     clean_trajectories_with_few_points(
-        move_df, label_id, min_points_per_trajectory, inplace=True
+        move_data, label_id, min_points_per_trajectory, inplace=True
     )
 
-    if DIST_TO_PREV not in move_df:
-        move_df.generate_dist_features(
+    if DIST_TO_PREV not in move_data:
+        move_data.generate_dist_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print('\n...Dropping unnecessary trajectories...')
+    logger.debug('\n...Dropping unnecessary trajectories...')
 
-    if move_df.index.name is not None:
-        print('reseting index')
-        move_df.reset_index(inplace=True)
+    if move_data.index.name is not None:
+        logger.debug('reseting index')
+        move_data.reset_index(inplace=True)
 
-    move_dataagg_tid = move_df.groupby(by=label_id).agg(
+    move_dataagg_tid = move_data.groupby(by=label_id).agg(
         {DIST_TO_PREV: 'sum'}
     )
     filter_ = move_dataagg_tid[DIST_TO_PREV] < min_trajectory_distance
     tid_selection = move_dataagg_tid[filter_].index
 
-    print(
+    logger.debug(
         '\n...short trajectories and trajectories with a minimum distance (%s): %s'
         % (move_dataagg_tid.shape[0], min_trajectory_distance)
     )
-    print('\n...There are %s tid do drop' % tid_selection.shape[0])
-    shape_before_drop = move_df.shape
+    logger.debug('\n...There are %s tid do drop' % tid_selection.shape[0])
+    shape_before_drop = move_data.shape
 
-    idx = move_df[move_df[label_id].isin(tid_selection)].index
+    idx = move_data[move_data[label_id].isin(tid_selection)].index
     if idx.shape[0] > 0:
-        tids_before_drop = move_df[label_id].unique().shape[0]
-        print(
+        tids_before_drop = move_data[label_id].unique().shape[0]
+        logger.debug(
             '\n...Tids - before drop: %s - after drop: %s'
-            % (tids_before_drop, move_df[label_id].unique().shape[0])
+            % (tids_before_drop, move_data[label_id].unique().shape[0])
         )
-        move_df.drop(index=idx, inplace=True)
-        print(
+        move_data.drop(index=idx, inplace=True)
+        logger.debug(
             '\n...Shape - before drop: %s - after drop: %s'
-            % (shape_before_drop, move_df.shape)
+            % (shape_before_drop, move_data.shape)
         )
 
     if not inplace:
-        return move_df
+        return move_data
 
 
 def clean_id_by_time_max(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    time_max: Optional[float] = 3600,
-    label_dtype: Optional[Callable] = np.float64,
-    inplace: Optional[bool] = False,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    time_max: float = 3600,
+    label_dtype: Callable = np.float64,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Clears GPS points with time by ID greater than a user-defined limit.
 
@@ -973,42 +895,39 @@ def clean_id_by_time_max(
         The filtered trajectories with the maximum time.
 
     """
-
     if not inplace:
-        move_df = move_data[:]
-    else:
-        move_df = move_data
+        move_data = move_data.copy()
 
-    if TIME_TO_PREV not in move_df:
-        move_df.generate_dist_time_speed_features(
+    if TIME_TO_PREV not in move_data:
+        move_data.generate_dist_time_speed_features(
             label_id=label_id, label_dtype=label_dtype
         )
 
-    print(
+    logger.debug(
         '\nClean gps points with time max by id < %s seconds'
         % time_max
     )
     move_dataid_drop = (
-        move_df.groupby([label_id], as_index=False)
+        move_data.groupby([label_id], as_index=False)
         .agg({TIME_TO_PREV: 'sum'})
-        .query('%s < %s' % (TIME_TO_PREV, time_max))
+        .query(f'{TIME_TO_PREV} < {time_max}')
     )
-    print(
+    logger.debug(
         '...Ids total: %s\nIds to drop:%s'
         % (
-            move_df[label_id].nunique(),
+            move_data[label_id].nunique(),
             move_dataid_drop[label_id].nunique()
         )
     )
     if move_dataid_drop.shape[0] > 0:
-        before_drop = move_df.shape[0]
-        filter_ = move_df[label_id].isin(move_dataid_drop[label_id])
-        idx = move_df[filter_].index
-        move_df.drop(idx, inplace=True)
-        print(
+        before_drop = move_data.shape[0]
+        filter_ = move_data[label_id].isin(move_dataid_drop[label_id])
+        idx = move_data[filter_].index
+        move_data.drop(idx, inplace=True)
+        logger.debug(
             '...Rows before drop: %s\n Rows after drop: %s'
-            % (before_drop, move_df.shape[0])
+            % (before_drop, move_data.shape[0])
         )
 
     if not inplace:
-        return move_df
+        return move_data
