@@ -1,4 +1,16 @@
-from typing import TYPE_CHECKING, Optional, Text, Tuple, Union
+"""
+Compression operations.
+
+bbox_split,
+by_dist_time_speed,
+by_max_dist,
+by_max_time,
+by_max_speed
+
+"""
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pandas as pd
@@ -15,17 +27,17 @@ from pymove.utils.constants import (
     TIME_TO_PREV,
     TRAJ_ID,
 )
-from pymove.utils.log import progress_bar, timer_decorator
+from pymove.utils.log import logger, progress_bar, timer_decorator
 
 if TYPE_CHECKING:
-    from pymove.core.pandas import PandasMoveDataFrame
     from pymove.core.dask import DaskMoveDataFrame
+    from pymove.core.pandas import PandasMoveDataFrame
 
 
 @timer_decorator
-def bbox_split(bbox: Tuple[int, int, int, int], number_grids: int) -> DataFrame:
+def bbox_split(bbox: tuple[int, int, int, int], number_grids: int) -> DataFrame:
     """
-    splits the bounding box in N grids of the same size.
+    Splits the bounding box in N grids of the same size.
 
     Parameters
     ----------
@@ -42,7 +54,6 @@ def bbox_split(bbox: Tuple[int, int, int, int], number_grids: int) -> DataFrame:
         the grids after the split.
 
     """
-
     lat_min = bbox[0]
     lon_min = bbox[1]
     lat_max = bbox[2]
@@ -50,7 +61,7 @@ def bbox_split(bbox: Tuple[int, int, int, int], number_grids: int) -> DataFrame:
 
     const_lat = abs(abs(lat_max) - abs(lat_min)) / number_grids
     const_lon = abs(abs(lon_max) - abs(lon_min)) / number_grids
-    print('const_lat: %s\nconst_lon: %s' % (const_lat, const_lon))
+    logger.debug(f'const_lat: {const_lat}\nconst_lon: {const_lon}')
 
     move_data = pd.DataFrame(
         columns=['lat_min', 'lon_min', 'lat_max', 'lon_max']
@@ -69,7 +80,7 @@ def bbox_split(bbox: Tuple[int, int, int, int], number_grids: int) -> DataFrame:
     return move_data
 
 
-def _drop_single_point(move_data: DataFrame, label_new_tid: Text, label_id: Text):
+def _drop_single_point(move_data: DataFrame, label_new_tid: str, label_id: str):
     """
     Removes trajectory with single point.
 
@@ -84,30 +95,31 @@ def _drop_single_point(move_data: DataFrame, label_new_tid: Text, label_id: Text
          Indicates the label of the id column in the user dataframe, by default TRAJ_ID
 
     """
-
     shape_before_drop = move_data.shape
     idx = move_data[move_data[label_new_tid] == -1].index
     if idx.shape[0] > 0:
-        print('...Drop Trajectory with a unique GPS point\n')
+        logger.debug('...Drop Trajectory with a unique GPS point\n')
         ids_before_drop = move_data[label_id].unique().shape[0]
         move_data.drop(index=idx, inplace=True)
-        print(
-            '...Object - before drop: %s - after drop: %s'
-            % (ids_before_drop, move_data[label_id].unique().shape[0])
+        logger.debug(
+            '...Object - before drop: {} - after drop: {}'.format(
+                ids_before_drop, move_data[label_id].unique().shape[0]
+            )
         )
-        print(
-            '...Shape - before drop: %s - after drop: %s'
-            % (shape_before_drop, move_data.shape)
+        logger.debug(
+            '...Shape - before drop: {} - after drop: {}'.format(
+                shape_before_drop, move_data.shape
+            )
         )
     else:
-        print('...No trajs with only one point.', move_data.shape)
+        logger.debug('...No trajectories with only one point.')
 
 
 def _filter_and_dist_time_speed(
     move_data: DataFrame, idx: int, max_dist: float, max_time: float, max_speed: float
 ) -> ndarray:
     """
-    Filters the dataframe considering thresholds for time, dist and speed
+    Filters the dataframe considering thresholds for time, dist and speed.
 
     Parameters
     ----------
@@ -128,7 +140,6 @@ def _filter_and_dist_time_speed(
         filtered indexes from the dataframe
 
     """
-
     return (
         (np.nan_to_num(move_data.at[idx, DIST_TO_PREV]) > max_dist)
         | (np.nan_to_num(move_data.at[idx, TIME_TO_PREV]) > max_time)
@@ -137,10 +148,10 @@ def _filter_and_dist_time_speed(
 
 
 def _filter_or_dist_time_speed(
-    move_data: DataFrame, idx: int, feature: Text, max_between_adj_points: float
+    move_data: DataFrame, idx: int, feature: str, max_between_adj_points: float
 ) -> ndarray:
     """
-    Filters the dataframe considering thresholds for time, dist and speed
+    Filters the dataframe considering thresholds for time, dist and speed.
 
     Parameters
     ----------
@@ -159,14 +170,12 @@ def _filter_or_dist_time_speed(
         filtered indexes from the dataframe
 
     """
-
     return np.nan_to_num(move_data.at[idx, feature]) > max_between_adj_points
 
 
-def _prepare_segmentation(move_data: DataFrame, label_id: Text, label_new_tid: Text):
+def _prepare_segmentation(move_data: DataFrame, label_id: str, label_new_tid: str):
     """
-    Resets the dataframe index, collects unique ids and
-    initiates curr_id and count
+    Resets the dataframe index, collects unique ids and initiates curr_id and count.
 
     Parameters
     ----------
@@ -187,9 +196,8 @@ def _prepare_segmentation(move_data: DataFrame, label_id: Text, label_new_tid: T
         initial count
 
     """
-
     if move_data.index.name is None:
-        print('...setting %s as index' % label_id, flush=True)
+        logger.debug(f'...setting {label_id} as index')
         move_data.set_index(label_id, inplace=True)
     curr_tid = 0
     if label_new_tid not in move_data:
@@ -202,10 +210,10 @@ def _prepare_segmentation(move_data: DataFrame, label_id: Text, label_new_tid: T
 
 def _update_curr_tid_count(
     filter_: ndarray, move_data: DataFrame, idx: int,
-    label_new_tid: Text, curr_tid: float, count: int
-) -> Tuple[int, int]:
+    label_new_tid: str, curr_tid: int, count: int
+) -> tuple[int, int]:
     """
-    Updates the tid
+    Updates the tid.
 
     Parameters
     ----------
@@ -230,10 +238,9 @@ def _update_curr_tid_count(
         updated count ids
 
     """
-
     curr_tid += 1
     if filter_.shape == ():
-        print('id: %s has no point to split' % idx)
+        logger.debug(f'id: {idx} has no point to split')
         move_data.at[idx, label_new_tid] = curr_tid
         count += 1
     else:
@@ -249,7 +256,7 @@ def _update_curr_tid_count(
 
 
 def _filter_by(
-    move_data: DataFrame, label_id: Text, label_new_tid: Text,
+    move_data: DataFrame, label_id: str, label_new_tid: str,
     drop_single_points: bool, **kwargs
 ) -> DataFrame:
     """
@@ -286,7 +293,6 @@ def _filter_by(
     Time, distance and speed features must be updated after split.
 
     """
-
     curr_tid, ids, count = _prepare_segmentation(
         move_data, label_id, label_new_tid
     )
@@ -314,10 +320,10 @@ def _filter_by(
 
     if label_id == label_new_tid:
         move_data.reset_index(drop=True, inplace=True)
-        print('... label_tid = label_new_id, then reseting and drop index')
+        logger.debug('... label_tid = label_new_id, then reseting and drop index')
     else:
         move_data.reset_index(inplace=True)
-        print('... Reseting index\n')
+        logger.debug('... Reseting index\n')
 
     if drop_single_points:
         _drop_single_point(move_data, label_new_tid, label_id)
@@ -328,15 +334,15 @@ def _filter_by(
 
 @timer_decorator
 def by_dist_time_speed(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    max_dist_between_adj_points: Optional[float] = 3000,
-    max_time_between_adj_points: Optional[float] = 7200,
-    max_speed_between_adj_points: Optional[float] = 50.0,
-    drop_single_points: Optional[bool] = True,
-    label_new_tid: Optional[Text] = TID_PART,
-    inplace: Optional[bool] = True,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    max_dist_between_adj_points: float = 3000,
+    max_time_between_adj_points: float = 900,
+    max_speed_between_adj_points: float = 50.0,
+    drop_single_points: bool = True,
+    label_new_tid: str = TID_PART,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Splits the trajectories into segments based on distance, time and speed.
 
@@ -350,7 +356,7 @@ def by_dist_time_speed(
         Specify the maximum distance a point should have from
         the previous point, in order not to be dropped, by default 3000
     max_time_between_adj_points : float, optional
-        Specify the maximum travel time between two adjacent points, by default 7200
+        Specify the maximum travel time between two adjacent points, by default 900
     max_speed_between_adj_points : float, optional
         Specify the maximum speed of travel between two adjacent points, by default 50
     drop_single_points : boolean, optional
@@ -361,7 +367,7 @@ def by_dist_time_speed(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to
         contain the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
     -------
@@ -375,14 +381,19 @@ def by_dist_time_speed(
     Time, distance and speed features must be updated after split.
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print('\nSplit trajectories')
-    print('...max_dist_between_adj_points:', max_dist_between_adj_points)
-    print('...max_time_between_adj_points:', max_time_between_adj_points)
-    print('...max_speed_between_adj_points:', max_speed_between_adj_points)
+    logger.debug('\nSplit trajectories')
+    logger.debug('...max_dist_between_adj_points: {}'.format(
+        max_dist_between_adj_points
+    ))
+    logger.debug('...max_time_between_adj_points: {}'.format(
+        max_time_between_adj_points
+    ))
+    logger.debug('...max_speed_between_adj_points: {}'.format(
+        max_speed_between_adj_points
+    ))
 
     if TIME_TO_PREV not in move_data:
         move_data.generate_dist_time_speed_features()
@@ -403,13 +414,13 @@ def by_dist_time_speed(
 
 @timer_decorator
 def by_max_dist(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    max_dist_between_adj_points: Optional[float] = 7200,
-    drop_single_points: Optional[bool] = True,
-    label_new_tid: Optional[Text] = TID_DIST,
-    inplace: Optional[bool] = True,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    max_dist_between_adj_points: float = 3000,
+    drop_single_points: bool = True,
+    label_new_tid: str = TID_DIST,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Segments the trajectories based on distance.
 
@@ -420,7 +431,7 @@ def by_max_dist(
     label_id : str, optional
          Indicates the label of the id column in the user dataframe, by default TRAJ_ID
     max_dist_between_adj_points : float, optional
-        Specify the maximum dist between two adjacent points, by default 7200
+        Specify the maximum dist between two adjacent points, by default 3000
     drop_single_points : boolean, optional
         If set to True, drops the trajectories with only one point, by default True
     label_new_tid : str, optional
@@ -430,7 +441,7 @@ def by_max_dist(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to
         contain the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
     -------
@@ -443,13 +454,13 @@ def by_max_dist(
     Speed features must be updated after split.
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print(
-        'Split trajectories by max distance between adjacent points:',
-        max_dist_between_adj_points,
+    logger.debug(
+        'Split trajectories by max distance between adjacent points: {}'.format(
+            max_dist_between_adj_points
+        )
     )
 
     if DIST_TO_PREV not in move_data:
@@ -470,13 +481,13 @@ def by_max_dist(
 
 @timer_decorator
 def by_max_time(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    max_time_between_adj_points: Optional[float] = 900.0,
-    drop_single_points: Optional[bool] = True,
-    label_new_tid: Optional[Text] = TID_TIME,
-    inplace: Optional[Text] = True,
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    max_time_between_adj_points: float = 900.0,
+    drop_single_points: bool = True,
+    label_new_tid: str = TID_TIME,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Splits the trajectories into segments based on a maximum.
 
@@ -497,7 +508,7 @@ def by_max_time(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to
         contain the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
 
     Returns
@@ -511,13 +522,13 @@ def by_max_time(
     Speed features must be updated after split.
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print(
-        'Split trajectories by max_time_between_adj_points:',
-        max_time_between_adj_points,
+    logger.debug(
+        'Split trajectories by max_time_between_adj_points: {}'.format(
+            max_time_between_adj_points
+        )
     )
 
     if TIME_TO_PREV not in move_data:
@@ -538,13 +549,13 @@ def by_max_time(
 
 @timer_decorator
 def by_max_speed(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    label_id: Optional[Text] = TRAJ_ID,
-    max_speed_between_adj_points: Optional[float] = 50.0,
-    drop_single_points: Optional[bool] = True,
-    label_new_tid: Optional[Text] = TID_SPEED,
-    inplace: Optional[bool] = True,
-) -> Union['PandasMoveDataFrame', 'DaskMoveDataFrame']:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    label_id: str = TRAJ_ID,
+    max_speed_between_adj_points: float = 50.0,
+    drop_single_points: bool = True,
+    label_new_tid: str = TID_SPEED,
+    inplace: bool = False,
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Splits the trajectories into segments based on a maximum speed.
 
@@ -565,7 +576,7 @@ def by_max_speed(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to
         contain the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
     -------
@@ -578,13 +589,13 @@ def by_max_speed(
     Speed features must be updated after split.
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print(
-        'Split trajectories by max_speed_between_adj_points:',
-        max_speed_between_adj_points,
+    logger.debug(
+        'Split trajectories by max_speed_between_adj_points: {}'.format(
+            max_speed_between_adj_points
+        )
     )
 
     if SPEED_TO_PREV not in move_data:
