@@ -1,4 +1,20 @@
-from typing import TYPE_CHECKING, Optional, Text, Tuple, Union
+"""
+Semantic operations.
+
+outliers
+create_or_update_out_of_the_bbox,
+create_or_update_gps_deactivated_signal,
+create_or_update_gps_jump,
+create_or_update_short_trajectory,
+create_or_update_gps_block_signal,
+filter_block_signal_by_repeated_amount_of_points,
+filter_block_signal_by_time,
+filter_longer_time_to_stop_segment_by_id
+
+"""
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import numpy as np
 from pandas import DataFrame
@@ -7,28 +23,33 @@ from pymove.preprocessing import filters, segmentation, stay_point_detection
 from pymove.utils.constants import (
     BLOCK,
     DEACTIVATED,
+    DIST_PREV_TO_NEXT,
+    DIST_TO_NEXT,
     DIST_TO_PREV,
     JUMP,
     OUT_BBOX,
+    OUTLIER,
     SEGMENT_STOP,
     SHORT,
     TID_PART,
     TIME_TO_PREV,
     TRAJ_ID,
 )
-from pymove.utils.log import timer_decorator
+from pymove.utils.log import logger, timer_decorator
 
 if TYPE_CHECKING:
-    from pymove.core.pandas import PandasMoveDataFrame
     from pymove.core.dask import DaskMoveDataFrame
+    from pymove.core.pandas import PandasMoveDataFrame
 
 
 def _end_create_operation(
-    move_data: DataFrame, new_label: Text, inplace: bool
-) -> Optional[DataFrame]:
+    move_data: DataFrame, new_label: str, inplace: bool
+) -> DataFrame | None:
     """
-    Returns the dataframe after create operation
+    Returns the dataframe after create operation.
 
+    Parameters
+    ----------
     move_data: dataframe
         The input trajectories data.
     new_label: string
@@ -38,23 +59,24 @@ def _end_create_operation(
         the result of the filtering, otherwise a copy will be returned.
 
     Returns
-    _______
+    -------
     DataFrame
         DataFrame with the additional features or None
 
     """
-
-    print(move_data[new_label].value_counts())
+    logger.debug(move_data[new_label].value_counts())
     if not inplace:
         return move_data
 
 
 def _process_simple_filter(
-    move_data: DataFrame, new_label: Text, feature: Text, value: float, inplace: bool
-) -> Optional[DataFrame]:
+    move_data: DataFrame, new_label: str, feature: str, value: float, inplace: bool
+) -> DataFrame | None:
     """
-    Processes create operation with simple filter
+    Processes create operation with simple filter.
 
+    Parameters
+    ----------
     move_data: dataframe
         The input trajectories data.
     new_label: string
@@ -68,12 +90,11 @@ def _process_simple_filter(
         the result of the filtering, otherwise a copy will be returned.
 
     Returns
-    _______
+    -------
     DataFrame
         DataFrame with the additional features or None
 
     """
-
     move_data[new_label] = False
     filter_ = move_data[feature] >= value
     idx_start = move_data[filter_].index
@@ -86,18 +107,82 @@ def _process_simple_filter(
     )
 
 
+@timer_decorator
+def outliers(
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    jump_coefficient: float = 3.0,
+    threshold: float = 1,
+    new_label: str = OUTLIER,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
+    """
+    Create or update a boolean feature to detect outliers.
+
+    Parameters
+    ----------
+    move_data : dataframe
+        The input trajectory data
+    jump_coefficient : float, optional
+        by default 3
+    threshold : float, optional
+        Minimum value that the distance features must have
+        in order to be considered outliers, by default 1
+    new_label: string, optional
+        The name of the new feature with detected points out of the bbox,
+        by default OUTLIER
+    inplace : bool, optional
+        if set to true the original dataframe will be altered to contain
+        the result of the filtering, otherwise a copy will be returned, by default False
+
+    Returns
+    -------
+    DataFrame
+        Returns a dataframe with the trajectories outliers or None
+
+    """
+    if not inplace:
+        move_data = move_data.copy()
+
+    if DIST_TO_PREV not in move_data:
+        move_data.generate_dist_features()
+
+    if move_data.index.name is not None:
+        logger.debug('...Reset index for filtering\n')
+        move_data.reset_index(inplace=True)
+
+    if (
+        DIST_TO_PREV in move_data
+        and DIST_TO_NEXT
+        and DIST_PREV_TO_NEXT in move_data
+    ):
+        jump = jump_coefficient * move_data[DIST_PREV_TO_NEXT]
+        filter_ = (
+            (move_data[DIST_TO_NEXT] > threshold)
+            & (move_data[DIST_TO_PREV] > threshold)
+            & (move_data[DIST_PREV_TO_NEXT] > threshold)
+            & (jump < move_data[DIST_TO_NEXT])
+            & (jump < move_data[DIST_TO_PREV])
+        )
+        move_data[new_label] = filter_
+    else:
+        logger.warning('...Distances features were not created')
+
+    if not inplace:
+        return move_data
+
+
 @timer_decorator
 def create_or_update_out_of_the_bbox(
     move_data: DataFrame,
-    bbox: Tuple[int, int, int, int],
-    new_label: Optional[Text] = OUT_BBOX,
-    inplace: Optional[bool] = True
-) -> Optional[DataFrame]:
+    bbox: tuple[int, int, int, int],
+    new_label: str = OUT_BBOX,
+    inplace: bool = False
+) -> DataFrame | None:
     """
     Create or update a boolean feature to detect points out of the bbox.
 
     Parameters
-    __________
+    ----------
     move_data: dataframe
         The input trajectories data.
     bbox : tuple
@@ -109,26 +194,33 @@ def create_or_update_out_of_the_bbox(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         Returns dataframe with a boolean feature with detected
         points out of the bbox, or None
 
+    Raises
+    ------
+    ValueError
+        If feature generation fails
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print('\nCreate or update boolean feature to detect points out of the bbox')
+    logger.debug('\nCreate or update boolean feature to detect points out of the bbox')
     filtered_ = filters.by_bbox(move_data, bbox, filter_out=True)
 
-    print('...Creating a new label named as %s' % new_label)
+    if filtered_ is None:
+        raise ValueError('Filter bbox failed!')
+
+    logger.debug('...Creating a new label named as %s' % new_label)
     move_data[new_label] = False
+
     if filtered_.shape[0] > 0:
-        print('...Setting % as True\n' % new_label)
+        logger.debug('...Setting % as True\n' % new_label)
         move_data.at[filtered_.index, new_label] = True
 
     return _end_create_operation(
@@ -138,17 +230,19 @@ def create_or_update_out_of_the_bbox(
 
 @timer_decorator
 def create_or_update_gps_deactivated_signal(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    max_time_between_adj_points: Optional[float] = 7200,
-    new_label: Optional[Text] = DEACTIVATED,
-    inplace: Optional[bool] = True
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    max_time_between_adj_points: float = 7200,
+    new_label: str = DEACTIVATED,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Create or update a feature deactivate_signal if the max time between
-    adjacent points is equal or less than max_time_between_adj_points.
+    Creates a new feature that inform if point invalid.
+
+    If the max time between adjacent points is equal or
+    less than max_time_between_adj_points.
 
     Parameters
-    __________
+    ----------
     move_data: dataframe
         The input trajectories data.
     max_time_between_adj_points: float, optional
@@ -159,21 +253,20 @@ def create_or_update_gps_deactivated_signal(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         DataFrame with the additional features or None
         'time_to_prev', 'time_to_next', 'time_prev_to_next', 'deactivate_signal'
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    message = 'Create or update deactivated signal if time max > %srs seconds\n'
-    print(message % max_time_between_adj_points)
+    message = 'Create or update deactivated signal if time max > %s seconds\n'
+    logger.debug(message % max_time_between_adj_points)
     move_data.generate_time_features()
 
     return _process_simple_filter(
@@ -187,17 +280,19 @@ def create_or_update_gps_deactivated_signal(
 
 @timer_decorator
 def create_or_update_gps_jump(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    max_dist_between_adj_points: Optional[float] = 3000,
-    new_label: Optional[Text] = JUMP,
-    inplace: Optional[bool] = True
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    max_dist_between_adj_points: float = 3000,
+    new_label: str = JUMP,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Create or update Jump if the maximum distance between adjacent
-    points is greater than max_dist_between_adj_points.
+    Creates a new feature that inform if point is a gps jump.
+
+    A jump is defined if the maximum distance between adjacent points
+    is greater than max_dist_between_adj_points.
 
     Parameters
-    __________
+    ----------
     move_data: dataframe
         The input trajectories data.
     max_dist_between_adj_points: float, optional
@@ -207,21 +302,20 @@ def create_or_update_gps_jump(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         DataFrame with the additional features or None
         'dist_to_prev', 'dist_to_next', 'dist_prev_to_next', 'jump'
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    message = 'Create or update jump if dist max > %srs meters\n'
-    print(message % max_dist_between_adj_points)
+    message = 'Create or update jump if dist max > %s meters\n'
+    logger.debug(message % max_dist_between_adj_points)
     move_data.generate_dist_features()
 
     return _process_simple_filter(
@@ -235,16 +329,17 @@ def create_or_update_gps_jump(
 
 @timer_decorator
 def create_or_update_short_trajectory(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    max_dist_between_adj_points: Optional[float] = 3000,
-    max_time_between_adj_points: Optional[float] = 7200,
-    max_speed_between_adj_points: Optional[float] = 50,
-    k_segment_max: Optional[int] = 50,
-    label_tid: Optional[Text] = TID_PART,
-    new_label: Optional[Text] = SHORT,
-    inplace: Optional[bool] = True
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    max_dist_between_adj_points: float = 3000,
+    max_time_between_adj_points: float = 7200,
+    max_speed_between_adj_points: float = 50,
+    k_segment_max: int = 50,
+    label_tid: str = TID_PART,
+    new_label: str = SHORT,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
+    Creates a new feature that inform if point belongs to a short trajectory.
 
     Parameters
     ----------
@@ -267,7 +362,7 @@ def create_or_update_short_trajectory(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
     -------
@@ -276,18 +371,18 @@ def create_or_update_short_trajectory(
        'dist_to_prev', 'time_to_prev', 'speed_to_prev', 'tid_part', 'short_traj'
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    print('\nCreate or update short trajectories...')
+    logger.debug('\nCreate or update short trajectories...')
 
     segmentation.by_dist_time_speed(
         move_data,
         max_dist_between_adj_points=max_dist_between_adj_points,
         max_time_between_adj_points=max_time_between_adj_points,
         max_speed_between_adj_points=max_speed_between_adj_points,
-        label_new_tid=label_tid
+        label_new_tid=label_tid,
+        inplace=True
     )
     move_data[new_label] = False
 
@@ -303,17 +398,17 @@ def create_or_update_short_trajectory(
 
 @timer_decorator
 def create_or_update_gps_block_signal(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    max_time_stop: Optional[float] = 7200,
-    new_label: Optional[Text] = BLOCK,
-    label_tid: Optional[Text] = TID_PART,
-    inplace: Optional[bool] = True
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    max_time_stop: float = 7200,
+    new_label: str = BLOCK,
+    label_tid: str = TID_PART,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
-    Create a new feature that inform points with speed = 0
+    Creates a new feature that inform segments with periods without moving.
 
     Parameters
-    __________
+    ----------
     move_data: dataFrame
         The input trajectories data.
     max_time_stop: float, optional
@@ -327,32 +422,33 @@ def create_or_update_gps_block_signal(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         DataFrame with the additional features or None
         'dist_to_prev', 'time_to_prev', 'speed_to_prev',
         'tid_dist', 'block_signal'
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
-    message = 'Create or update block_signal if max time stop > %srs seconds\n'
-    print(message % max_time_stop)
+    message = 'Create or update block_signal if max time stop > %s seconds\n'
+    logger.debug(message % max_time_stop)
     segmentation.by_max_dist(
-        move_data, max_dist_between_adj_points=0.0, label_new_tid=label_tid
+        move_data,
+        max_dist_between_adj_points=0.0,
+        label_new_tid=label_tid,
+        inplace=True
     )
 
-    print('Updating dist time speed values')
+    logger.debug('Updating dist time speed values')
     move_data.generate_dist_time_speed_features(label_id=label_tid)
 
     move_data[new_label] = False
 
-    # SUM the segment block to detect the id that has or more time stopped
     df_agg_tid = move_data.groupby(by=label_tid).agg({TIME_TO_PREV: 'sum'})
     filter_ = df_agg_tid[TIME_TO_PREV] >= max_time_stop
     idx = df_agg_tid[filter_].index
@@ -365,18 +461,18 @@ def create_or_update_gps_block_signal(
 
 @timer_decorator
 def filter_block_signal_by_repeated_amount_of_points(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    amount_max_of_points_stop: Optional[float] = 30.0,
-    max_time_stop: Optional[float] = 7200,
-    filter_out: Optional[bool] = False,
-    label_tid: Optional[Text] = TID_PART,
-    inplace: Optional[bool] = False
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    amount_max_of_points_stop: float = 30.0,
+    max_time_stop: float = 7200,
+    filter_out: bool = False,
+    label_tid: str = TID_PART,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Filters from dataframe points with blocked signal by amount of points.
 
     Parameters
-    __________
+    ----------
     move_data: dataFrame
         The input trajectories data.
     amount_max_of_points_stop: float, optional
@@ -392,23 +488,22 @@ def filter_block_signal_by_repeated_amount_of_points(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         Filtered DataFrame with the additional features or None
         'dist_to_prev', 'time_to_prev', 'speed_to_prev',
         'tid_dist', 'block_signal'
 
     """
-
     if not inplace:
-        move_data = move_data[:]
+        move_data = move_data.copy()
 
     if BLOCK not in move_data:
         create_or_update_gps_block_signal(
-            move_data, max_time_stop, label_tid=label_tid
+            move_data, max_time_stop, label_tid=label_tid, inplace=True
         )
 
     df_count_tid = move_data.groupby(by=[label_tid]).sum()
@@ -427,17 +522,17 @@ def filter_block_signal_by_repeated_amount_of_points(
 
 @timer_decorator
 def filter_block_signal_by_time(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    max_time_stop: Optional[float] = 7200,
-    filter_out: Optional[bool] = False,
-    label_tid: Optional[Text] = TID_PART,
-    inplace: Optional[bool] = False
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    max_time_stop: float = 7200,
+    filter_out: bool = False,
+    label_tid: str = TID_PART,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Filters from dataframe points with blocked signal by time.
 
     Parameters
-    __________
+    ----------
     move_data: dataFrame
         The input trajectories data.
     max_time_stop: float, optional
@@ -451,23 +546,22 @@ def filter_block_signal_by_time(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         Filtered DataFrame with the additional features or None
         'dist_to_prev', 'time_to_prev', 'speed_to_prev',
         'tid_dist', 'block_signal'
 
     """
-
     if not inplace:
         move_data = move_data.copy()
 
     if BLOCK not in move_data:
         create_or_update_gps_block_signal(
-            move_data, max_time_stop, label_tid=label_tid
+            move_data, max_time_stop, label_tid=label_tid, inplace=True
         )
 
     df_agg_tid = move_data.groupby(by=label_tid).agg(
@@ -489,19 +583,19 @@ def filter_block_signal_by_time(
 
 @timer_decorator
 def filter_longer_time_to_stop_segment_by_id(
-    move_data: Union['PandasMoveDataFrame', 'DaskMoveDataFrame'],
-    dist_radius: Optional[float] = 30,
-    time_radius: Optional[float] = 900,
-    label_id: Optional[Text] = TRAJ_ID,
-    label_segment_stop: Optional[Text] = SEGMENT_STOP,
-    filter_out: Optional[bool] = False,
-    inplace: Optional[bool] = False
-) -> Optional[Union['PandasMoveDataFrame', 'DaskMoveDataFrame']]:
+    move_data: 'PandasMoveDataFrame' | 'DaskMoveDataFrame',
+    dist_radius: float = 30,
+    time_radius: float = 900,
+    label_id: str = TRAJ_ID,
+    label_segment_stop: str = SEGMENT_STOP,
+    filter_out: bool = False,
+    inplace: bool = False
+) -> 'PandasMoveDataFrame' | 'DaskMoveDataFrame' | None:
     """
     Filters from dataframe segment with longest stop time.
 
     Parameters
-    __________
+    ----------
     move_data: dataFrame
         The input trajectories data.
     dist_radius : float, optional
@@ -520,23 +614,22 @@ def filter_longer_time_to_stop_segment_by_id(
     inplace : boolean, optional
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned,
-        by default True
+        by default False
 
     Returns
-    _______
+    -------
     DataFrame
         Filtered DataFrame with the additional features or None
         'dist_to_prev', 'time_to_prev', 'speed_to_prev',
         'tid_dist', 'block_signal'
 
     """
-
     if not inplace:
         move_data = move_data.copy()
 
     if label_segment_stop not in move_data:
         stay_point_detection.create_or_update_move_stop_by_dist_time(
-            move_data, dist_radius, time_radius
+            move_data, dist_radius, time_radius, inplace=True
         )
 
     df_agg_id_stop = move_data.groupby(
