@@ -52,7 +52,7 @@ def _assert_plot(map_info):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -66,7 +66,7 @@ def _assert_plot(map_info):
 
     assert (
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 2
         and count_l_popup == 2
         and count_head == 4
@@ -151,7 +151,7 @@ def test_heatmap(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.heatLayer')
 
@@ -162,7 +162,7 @@ def test_heatmap(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 1
            and count_head == 2
            and count_body == 3
@@ -204,7 +204,7 @@ def test_heatmap_with_time(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.heatLayer')
 
@@ -215,7 +215,7 @@ def test_heatmap_with_time(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 1
            and count_head == 2
            and count_body == 3
@@ -257,7 +257,7 @@ def test_cluster(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -271,7 +271,7 @@ def test_cluster(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 6
         and count_l_popup == 5
         and count_head == 2
@@ -317,7 +317,7 @@ def test_faster_cluster(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.circle')
 
@@ -328,7 +328,7 @@ def test_faster_cluster(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 1
            and count_head == 2
            and count_body == 3
@@ -370,7 +370,7 @@ def test_plot_markers(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -383,7 +383,7 @@ def test_plot_markers(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 5
            and count_l_popup == 5
            and count_head == 2
@@ -460,7 +460,7 @@ def test_filter_generated_feature():
         pass
 
 
-def test_add_begin_end_markers_to_folium_map(tmpdir):
+def test_add_begin_end_markers_to_map(tmpdir):
 
     move_df = _default_move_df()
 
@@ -471,7 +471,7 @@ def test_add_begin_end_markers_to_folium_map(tmpdir):
         tile=TILES[0],
         default_zoom_start=12)
 
-    folium._add_begin_end_markers_to_folium_map(move_df, base_map)
+    folium._add_begin_end_markers_to_map(move_df, base_map)
 
     d = tmpdir.mkdir('visualization')
 
@@ -490,7 +490,7 @@ def test_add_begin_end_markers_to_folium_map(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -504,7 +504,7 @@ def test_add_begin_end_markers_to_folium_map(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 2
         and count_l_popup == 2
         and count_head == 2
@@ -518,7 +518,7 @@ def test_add_begin_end_markers_to_folium_map(tmpdir):
                 '\n{"clusteredMarker":true,"color":"red"}') in map_info)
 
 
-def test_add_trajectories_to_folium_map(tmpdir):
+def test_add_trajectories_to_map(tmpdir):
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
@@ -550,7 +550,7 @@ def test_add_trajectories_to_folium_map(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.heatLayer')
 
@@ -562,7 +562,7 @@ def test_add_trajectories_to_folium_map(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 1
         and count_head == 2
         and count_body == 3
@@ -580,18 +580,18 @@ def test_add_trajectories_to_folium_map(tmpdir):
     )
 
 
-def test_plot_trajectories_with_folium(tmpdir):
+def test_plot_trajectories(tmpdir):
 
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
 
-    file_write_default = d.join('plot_trajectories_with_folium.html')
+    file_write_default = d.join('plot_trajectories.html')
     filename = os.path.join(
         file_write_default.dirname, file_write_default.basename
     )
 
-    base_map = folium.plot_trajectories_with_folium(
+    base_map = folium.plot_trajectories(
         move_df,
         n_rows=3,
         save_as_html=True,
@@ -609,7 +609,7 @@ def test_plot_trajectories_with_folium(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -622,7 +622,7 @@ def test_plot_trajectories_with_folium(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 2
            and count_l_popup == 2
            and count_head == 4
@@ -645,18 +645,18 @@ def test_plot_trajectories_with_folium(tmpdir):
     )
 
 
-def test_plot_trajectory_by_id_folium(tmpdir):
+def test_plot_trajectory_by_id(tmpdir):
 
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
 
-    file_write_default = d.join('plot_trajectory_by_id_folium.html')
+    file_write_default = d.join('plot_trajectory_by_id.html')
     filename_write_default = os.path.join(
         file_write_default.dirname, file_write_default.basename
     )
 
-    base_map = folium.plot_trajectory_by_id_folium(
+    base_map = folium.plot_trajectory_by_id(
         move_df,
         id_=1,
         save_as_html=True,
@@ -812,7 +812,7 @@ def test_plot_stops(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.circle')
 
@@ -825,7 +825,7 @@ def test_plot_stops(tmpdir):
     count_script = map_info.count('script')
 
     assert(count_l_map == 1
-           and count_l_tileLayer == 1
+           and count_l_title_layer == 1
            and count_l_marker == 3
            and count_l_popup == 3
            and count_head == 4
@@ -866,18 +866,18 @@ def test_plot_bbox(tmpdir):
     assert_equal(expected, actual)
 
 
-def test_plot_point_folium(tmpdir):
+def test_plot_point(tmpdir):
 
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
 
-    file_write_default = d.join('plot_point_folium.html')
+    file_write_default = d.join('plot_point.html')
     filename = os.path.join(
         file_write_default.dirname, file_write_default.basename
     )
 
-    base_map = folium.plot_points_folium(
+    base_map = folium.plot_points(
         move_data=move_df,
         user_lat=LATITUDE,
         user_lon=LONGITUDE,
@@ -899,7 +899,7 @@ def test_plot_point_folium(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -917,7 +917,7 @@ def test_plot_point_folium(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 0
         and count_l_popup == 5
         and count_l_polyline == 0
@@ -936,18 +936,18 @@ def test_plot_point_folium(tmpdir):
     )
 
 
-def test_plot_poi_folium(tmpdir):
+def test_plot_poi(tmpdir):
 
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
 
-    file_write_default = d.join('plot_point_folium.html')
+    file_write_default = d.join('plot_point.html')
     filename = os.path.join(
         file_write_default.dirname, file_write_default.basename
     )
 
-    base_map = folium.plot_poi_folium(
+    base_map = folium.plot_poi(
         move_data=move_df,
         poi_lat=LATITUDE,
         poi_lon=LONGITUDE,
@@ -968,7 +968,7 @@ def test_plot_poi_folium(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -986,7 +986,7 @@ def test_plot_poi_folium(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 0
         and count_l_popup == 5
         and count_l_polyline == 0
@@ -1005,18 +1005,18 @@ def test_plot_poi_folium(tmpdir):
     )
 
 
-def test_plot_event_folium(tmpdir):
+def test_plot_event(tmpdir):
 
     move_df = _default_move_df()
 
     d = tmpdir.mkdir('visualization')
 
-    file_write_default = d.join('plot_event_folium.html')
+    file_write_default = d.join('plot_event.html')
     filename = os.path.join(
         file_write_default.dirname, file_write_default.basename
     )
 
-    base_map = folium.plot_event_folium(
+    base_map = folium.plot_event(
         move_data=move_df,
         event_lat=LATITUDE,
         event_lon=LONGITUDE,
@@ -1039,7 +1039,7 @@ def test_plot_event_folium(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_title_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.marker')
 
@@ -1057,7 +1057,7 @@ def test_plot_event_folium(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_title_layer == 1
         and count_l_marker == 0
         and count_l_popup == 5
         and count_l_polyline == 0
@@ -1076,73 +1076,6 @@ def test_plot_event_folium(tmpdir):
     )
 
 
-def test_show_trajs_with_event():
-
-    move_df = _default_move_df()
-
-    df_event = move_df.iloc[0:3, :]
-
-    list_ = folium.show_trajs_with_event(
-        move_data=move_df,
-        window_time_subject=4,
-        df_event=df_event,
-        window_time_event=4,
-        radius=150,
-        event_lat=LATITUDE,
-        event_lon=LONGITUDE,
-        event_datetime=DATETIME,
-        user_lat=LATITUDE,
-        user_lon=LONGITUDE,
-        user_datetime=DATETIME,
-        event_id='id',
-        event_point=EVENT_POINT,
-        user_id='id',
-        user_point=USER_POINT,
-        line_color=LINE_COLOR,
-        slice_event_show=None,
-        slice_subject_show=None,
-    )
-
-    assert len(list_) == 3, 'list with wrong number of elements'
-    for i in list_:
-        base_map = i[0]
-        assert(base_map.control_scale is True)
-
-
-def test_show_traj_id_with_event():
-
-    move_df = _default_move_df()
-
-    df_event = move_df.iloc[0:3, :]
-
-    list_ = folium.show_traj_id_with_event(
-        move_data=move_df,
-        window_time_subject=4,
-        subject_id=1,
-        df_event=df_event,
-        window_time_event=4,
-        radius=150,
-        event_lat=LATITUDE,
-        event_lon=LONGITUDE,
-        event_datetime=DATETIME,
-        user_lat=LATITUDE,
-        user_lon=LONGITUDE,
-        user_datetime=DATETIME,
-        event_id='id',
-        event_point=EVENT_POINT,
-        user_id='id',
-        user_point=USER_POINT,
-        line_color=LINE_COLOR,
-        slice_event_show=None,
-        slice_subject_show=None,
-    )
-
-    assert type(list_) == tuple, 'Wrong type'
-    assert len(list_) == 2, 'list with wrong number of elements'
-    assert len(list_[1]) == 2
-    assert list_[0].control_scale is True
-
-
 def test_create_geojson_features_line():
 
     move_df = _default_move_df()
@@ -1191,7 +1124,7 @@ def test_plot_traj_timestamp_geo_json(tmpdir):
 
     count_l_map = map_info.count('L.map')
 
-    count_l_tileLayer = map_info.count('L.tileLayer')
+    count_l_tile_layer = map_info.count('L.tileLayer')
 
     count_l_marker = map_info.count('L.heatLayer')
 
@@ -1209,7 +1142,7 @@ def test_plot_traj_timestamp_geo_json(tmpdir):
 
     assert(
         count_l_map == 1
-        and count_l_tileLayer == 1
+        and count_l_tile_layer == 1
         and count_l_marker == 0
         and count_l_polyline == 0
         and count_l_circle == 2
