@@ -1,6 +1,18 @@
+"""
+Logging operations.
+
+progress_bar
+set_verbosity
+timer_decorator
+
+"""
+from __future__ import annotations
+
+import logging
+import os
 import time
 from functools import wraps
-from typing import Callable, Iterable, Optional, Text
+from typing import Callable, Iterable
 
 from IPython import get_ipython
 from IPython.display import display
@@ -9,8 +21,21 @@ from tqdm import tqdm as _tqdm
 
 from pymove.utils.datetime import deltatime_str
 
+LOG_LEVEL = os.getenv('PYMOVE_VERBOSE', 'INFO')
+logger = logging.getLogger('pymove')
+shell_handler = logging.StreamHandler()
+logger.setLevel(LOG_LEVEL)
+shell_handler.setLevel(LOG_LEVEL)
+logger.addHandler(shell_handler)
 
-def timer_decorator(func: Callable) -> wraps:
+
+def set_verbosity(level):
+    """Change logging level."""
+    logger.setLevel(level)
+    shell_handler.setLevel(level)
+
+
+def timer_decorator(func: Callable) -> Callable:
     """A decorator that prints how long a function took to run."""
 
     @wraps(func)
@@ -18,10 +43,8 @@ def timer_decorator(func: Callable) -> wraps:
         t_start = time.time()
         result = func(*args, **kwargs)
         t_total = deltatime_str(time.time() - t_start)
-        message = '%s took %s' % (func.__name__, t_total)
-        print('*' * len(message))
-        print(message)
-        print('*' * len(message))
+        message = f'{func.__name__} took {t_total}'
+        logger.debug('{}\n{}\n{}'.format('*' * len(message), message, '*' * len(message)))
         return result
 
     return wrapper
@@ -29,9 +52,9 @@ def timer_decorator(func: Callable) -> wraps:
 
 def _log_progress(
     sequence: Iterable,
-    desc: Optional[Text] = None,
-    total: Optional[int] = None,
-    miniters: Optional[int] = None
+    desc: str | None = None,
+    total: int | None = None,
+    miniters: int | None = None
 ):
     """
     Make and display a progress bar.
@@ -53,7 +76,7 @@ def _log_progress(
     is_iterator = False
     if total is None:
         try:
-            total = len(sequence)
+            total = len(sequence)  # type: ignore
         except TypeError:
             is_iterator = True
     if total is not None:
@@ -80,10 +103,10 @@ def _log_progress(
         for index, record in enumerate(sequence, 1):
             if index == 1 or index % miniters == 0:
                 if is_iterator:
-                    label.value = '%s: %s / ?' % (desc, index)
+                    label.value = f'{desc}: {index} / ?'
                 else:
                     progress.value = index
-                    label.value = u'%s: %s / %s' % (desc, index, total)
+                    label.value = f'{desc}: {index} / {total}'
             yield record
     except Exception:
         progress.bar_style = 'danger'
@@ -91,13 +114,45 @@ def _log_progress(
     else:
         progress.bar_style = 'success'
         progress.value = index
-        label.value = '%s: %s' % (desc, str(index or '?'))
+        label.value = '{}: {}'.format(desc, str(index or '?'))
 
 
 try:
     if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':
-        progress_bar = _log_progress
+        _log_progress_bar = _log_progress
     else:
         raise NameError
 except NameError:
-    progress_bar = _tqdm
+    _log_progress_bar = _tqdm
+
+
+def progress_bar(
+    sequence: Iterable,
+    desc: str | None = None,
+    total: int | None = None,
+    miniters: int | None = None
+):
+    """
+    Make and display a progress bar.
+
+    Parameters
+    ----------
+    sequence : iterable
+        Represents a sequence of elements.
+    desc : str, optional
+        Represents the description of the operation, by default None.
+    total : int, optional
+        Represents the total/number elements in sequence, by default None.
+    miniters : int, optional
+        Represents the steps in which the bar will be updated, by default None.
+
+    Return
+    ------
+    >>> from pymove.utils.log import progress_bar
+    >>> for i in progress_bar(range(1,101), desc='Print 1 to 100'):
+    >>>    print(i)
+    # A bar that shows the progress of the iterations
+    """
+    if logger.level > logging.INFO:
+        return sequence
+    return _log_progress_bar(sequence, desc, total, miniters)
