@@ -1,8 +1,22 @@
+"""
+Math operations.
+
+is_number,
+std,
+avg_std,
+std_sample,
+avg_std_sample,
+arrays_avg,
+array_stats,
+interpolation
+
+"""
+from __future__ import annotations
+
 import math
-from typing import List, Optional, Tuple, Union
 
 
-def is_number(value: Union[int, float, str]):
+def is_number(value: int | float | str):
     """
     Returns if value is numerical or not.
 
@@ -14,8 +28,20 @@ def is_number(value: Union[int, float, str]):
     -------
     boolean
         True if numerical, otherwise False
-    """
 
+    Examples
+    --------
+    >>> from pymove.utils.math import is_number
+    >>> a, b, c, d = 50, 22.5, '11.25', 'house'
+    >>> print(is_number(a), type(is_number(a)))
+    True <class 'bool'>
+    >>> print(is_number(b), type(is_number(b)))
+    True <class 'bool'>
+    >>> print(is_number(c), type(is_number(c)))
+    True <class 'bool'>
+    >>> print(is_number(d), type(is_number(d)))
+    False <class 'bool'>
+    """
     try:
         float(value)
     except ValueError:
@@ -23,7 +49,7 @@ def is_number(value: Union[int, float, str]):
     return True
 
 
-def std(values_array: List[float]) -> float:
+def std(values_array: list[float]) -> float:
     """
     Compute standard deviation.
 
@@ -42,16 +68,21 @@ def std(values_array: List[float]) -> float:
     squaring with * is over 3 times as fast as with **2
     http://stackoverflow.com/questions/29046346/comparison-of-power-to-multiplication-in-python
 
+    Example
+    -------
+    >>> from pymove.utils.math import std
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> print(std(list), type(std(list)))
+    1.7435595774162693 <class 'float'>
     """
-
     size = len(values_array)
     mean = sum(values_array) / size
-    sum_sq = sum([(i - mean) * (i - mean) for i in values_array])
+    sum_sq = sum((i - mean) * (i - mean) for i in values_array)
 
     return math.sqrt(sum_sq / size)
 
 
-def avg_std(values_array: List[float]) -> Tuple[float, float]:
+def avg_std(values_array: list[float]) -> tuple[float, float]:
     """
     Compute the average of standard deviation.
 
@@ -67,13 +98,18 @@ def avg_std(values_array: List[float]) -> Tuple[float, float]:
     float
         Represents the value of standard deviation.
 
+    Example
+    -------
+    >>> from pymove.utils.math import avg_std
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> print(avg_std(list), type(avg_std(list)))
+    1.9493588689617927 <class 'float'>
     """
-
     avg = sum(values_array) / len(values_array)
     return avg, std(values_array)
 
 
-def std_sample(values_array: List[float]) -> float:
+def std_sample(values_array: list[float]) -> float:
     """
     Compute the standard deviation of sample.
 
@@ -87,13 +123,18 @@ def std_sample(values_array: List[float]) -> float:
     float
         Represents the value of standard deviation of sample.
 
+    Example
+    -------
+    >>> from pymove.utils.math import std_sample
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> print(std_sample(list), type(std_sample(list)))
+    1.9493588689617927 <class 'float'>
     """
-
     size = len(values_array)
     return std(values_array) * math.sqrt(size / (size - 1))
 
 
-def avg_std_sample(values_array: List[float]) -> Tuple[float, float]:
+def avg_std_sample(values_array: list[float]) -> tuple[float, float]:
     """
     Compute the average of standard deviation of sample.
 
@@ -109,14 +150,19 @@ def avg_std_sample(values_array: List[float]) -> Tuple[float, float]:
     float
         Represents the standard deviation of sample.
 
+    Example
+    -------
+    >>> from pymove.utils.math import avg_std_sample
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> print(avg_std_sample(list), type(avg_std_sample(list)))
+    (7.9, 1.9493588689617927) <class 'tuple'>
     """
-
     avg = sum(values_array) / len(values_array)
     return avg, std_sample(values_array)
 
 
 def arrays_avg(
-    values_array: List[float], weights_array: Optional[List[float]] = None
+    values_array: list[float], weights_array: list[float] | None = None
 ) -> float:
     """
     Computes the mean of the elements of the array.
@@ -134,8 +180,20 @@ def arrays_avg(
     float
         The mean of the array elements.
 
+    Examples
+    --------
+    >>> from pymove.utils.math import arrays_avg
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> weights = [0.1, 0.3, 0.15, 0.15, 0.3]
+    >>> print('standard average', arrays_avg(list), type(arrays_avg(list)))
+    'standard average 7.9 <class 'float'>'
+    >>> print(
+    >>>    'weighted average: ',
+    >>>     arrays_avg(list, weights),
+    >>>     type(arrays_avg(list, weights))
+    >>> )
+    'weighted average:  1.6979999999999997 <class 'float'>'
     """
-
     n = len(values_array)
 
     if weights_array is None:
@@ -145,7 +203,7 @@ def arrays_avg(
             'values_array and qt_array must have the same number of rows'
         )
 
-    result = 0
+    result = 0.
 
     for i, j in zip(values_array, weights_array):
         result += i * j
@@ -153,9 +211,11 @@ def arrays_avg(
     return result / n
 
 
-def array_stats(values_array: List[float]) -> Tuple[float, float, int]:
+def array_stats(values_array: list[float]) -> tuple[float, float, int]:
     """
-    Computes the sum of all the elements in the array, the sum of the square of
+    Computes statistics about the array.
+
+    The sum of all the elements in the array, the sum of the square of
     each element and the number of elements of the array.
 
     Parameters
@@ -171,11 +231,15 @@ def array_stats(values_array: List[float]) -> Tuple[float, float, int]:
         The sum of the square value of each element in the array.
     int.
         The number of elements in the array.
-
+    Example
+    -------
+    >>> from pymove.utils.math import array_stats
+    >>> list = [7.8, 9.7, 6.4, 5.6, 10]
+    >>> print(array_stats(list), type(array_stats(list)))
+    (39.5, 327.25, 5) <class 'tuple'>
     """
-
-    sum_ = 0
-    sum_sq = 0
+    sum_ = 0.
+    sum_sq = 0.
     n = 0
     for item in values_array:
         sum_ += item
@@ -206,11 +270,11 @@ def interpolation(x0: float, y0: float, x1: float, y1: float, x: float) -> float
     float.
         Is the interpolated  or extrapolated value.
 
-    Examples
-    --------
-    - interpolation 1: (30, 3, 40, 5, 37) -> 4.4
-    - interpolation 2: (30, 3, 40, 5, 35) -> 4.0
-
+    Example
+    -------
+    >>> from pymove.utils.math import interpolation
+    >>> x0, y0, x1, y1, x = 2, 4, 3, 6, 3.5
+    >>> print(interpolation(x0,y0,x1,y1,x), type(interpolation(x0,y0,x1,y1,x)))
+    7.0 <class 'float'>
     """
-
     return y0 + (y1 - y0) * ((x - x0) / (x1 - x0))
